@@ -2,21 +2,19 @@
 # TODO: Let creator override js template
 import json
 from os import environ
-from string import Template as StringTemplate
 
 import geojson
 import numpy as np
 from crosscompute.routines.interface import Batch
 from crosscompute.routines.variable import (
     Element, VariableView, add_label_html)
-from jinja2 import Template as JinjaTemplate
 
 from ..constants import (
     DECK_JS_URI,
     MAPBOX_CSS_URI,
     MAPBOX_JS_URI,
-    TEMPLATES_FOLDER,
     TURF_JS_URI)
+from .asset import asset_storage
 
 
 class MapMapboxView(VariableView):
@@ -38,7 +36,7 @@ class MapMapboxView(VariableView):
         data_uri = b.get_data_uri(variable_definition, x)
         c = b.get_variable_configuration(variable_definition)
         main_text = get_map_html(
-            element_id, variable_id, c, self.mode_name, self.view_name,
+            element_id, variable_id, c, x.mode_name, self.view_name,
             x.design_name)
         js_texts = [
             "mapboxgl.accessToken = '%s';" % environ['MAPBOX_TOKEN'],
@@ -51,15 +49,10 @@ class MapMapboxView(VariableView):
                 'bounds': c.get('bounds'),
                 'map': get_map_definition(element_id, c, x.for_print),
                 'sources': get_source_definitions(element_id, c, data_uri),
-                'layers': get_layer_definitions(element_id, c),
-            }),
-        ]
+                'layers': get_layer_definitions(element_id, c)})]
         return {
-            'css_uris': self.css_uris,
-            'js_uris': self.js_uris,
-            'main_text': main_text,
-            'js_texts': js_texts,
-        }
+            'css_uris': self.css_uris, 'js_uris': self.js_uris,
+            'main_text': main_text, 'js_texts': js_texts}
 
 
 class MapMapboxLocationView(VariableView):
@@ -71,11 +64,10 @@ class MapMapboxLocationView(VariableView):
 
     def render_input(self, b: Batch, x: Element):
         variable_definition = self.variable_definition
-        variable_id = self.variable_id
         element_id = x.id
         view_name = self.view_name
         c = b.get_variable_configuration(variable_definition)
-        data = b.get_data(variable_definition)
+        data = b.load_data(variable_definition)
         if 'value' in data:
             v = data['value']
             try:
@@ -86,7 +78,7 @@ class MapMapboxLocationView(VariableView):
             c['longitude'], c['latitude'] = longitude, latitude
             c['zoom'] = zoom
         main_text = get_map_html(
-            element_id, variable_id, c, self.mode_name, view_name,
+            element_id, self.variable_id, c, x.mode_name, view_name,
             x.design_name, MAP_MAPBOX_LOCATION_INPUT_HTML.render({
                 'view_name': view_name, 'element_id': element_id}))
         js_texts = [
@@ -99,11 +91,8 @@ class MapMapboxLocationView(VariableView):
                 'map': get_map_definition(element_id, c, x.for_print)}),
         ]
         return {
-            'css_uris': self.css_uris,
-            'js_uris': self.js_uris,
-            'main_text': main_text,
-            'js_texts': js_texts,
-        }
+            'css_uris': self.css_uris, 'js_uris': self.js_uris,
+            'main_text': main_text, 'js_texts': js_texts}
 
 
 class MapDeckScreenGridView(VariableView):
@@ -126,7 +115,7 @@ class MapDeckScreenGridView(VariableView):
         c = b.get_variable_configuration(variable_definition)
         mapbox_token = environ['MAPBOX_TOKEN']
         main_text = get_map_html(
-            element_id, variable_id, c, self.mode_name, self.view_name,
+            element_id, variable_id, c, x.mode_name, self.view_name,
             x.design_name)
         js_texts = [
             f"mapboxgl.accessToken = '{mapbox_token}';",
@@ -143,15 +132,10 @@ class MapDeckScreenGridView(VariableView):
                 'longitude': c.get('longitude', 0),
                 'latitude': c.get('latitude', 0),
                 'zoom': c.get('zoom', 0),
-                'for_print': x.for_print,
-            }),
-        ]
+                'for_print': x.for_print})]
         return {
-            'css_uris': self.css_uris,
-            'js_uris': self.js_uris,
-            'main_text': main_text,
-            'js_texts': js_texts,
-        }
+            'css_uris': self.css_uris, 'js_uris': self.js_uris,
+            'main_text': main_text, 'js_texts': js_texts}
 
 
 def save_map_configuration(xy_array, source_path):
@@ -229,31 +213,26 @@ def get_layer_definitions(element_id, variable_configuration):
     return definitions
 
 
-def load_view_text(file_name):
-    return open(TEMPLATES_FOLDER / file_name).read().strip()
-
-
 MAP_MAPBOX_STYLE_URI = 'mapbox://styles/mapbox/dark-v10'
-MAP_MAPBOX_HTML = StringTemplate(load_view_text('mapbox.html'))
-MAP_MAPBOX_JS_HEADER = load_view_text(
-    'mapboxHeader.js')
 
 
-MAP_MAPBOX_OUTPUT_JS_HEADER = load_view_text(
-    'mapboxOutputHeader.js')
-MAP_MAPBOX_OUTPUT_JS_VARIABLE = JinjaTemplate(load_view_text(
-    'mapboxOutputVariable.js'), trim_blocks=True)
+MAP_MAPBOX_HTML = asset_storage.load_string_text('mapbox.html')
+MAP_MAPBOX_JS_HEADER = asset_storage.load_raw_text('mapbox-header.js')
+MAP_MAPBOX_OUTPUT_JS_HEADER = asset_storage.load_raw_text(
+    'mapbox-output-header.js')
+MAP_MAPBOX_OUTPUT_JS_VARIABLE = asset_storage.load_jinja_text(
+    'mapbox-output-variable.js')
 
 
-MAP_MAPBOX_LOCATION_INPUT_HTML = JinjaTemplate(load_view_text(
-    'mapboxLocationInput.html'), trim_blocks=True)
-MAP_MAPBOX_LOCATION_INPUT_JS_HEADER = JinjaTemplate(load_view_text(
-    'mapboxLocationInputHeader.js'), trim_blocks=True)
-MAP_MAPBOX_LOCATION_INPUT_JS_VARIABLE = JinjaTemplate(load_view_text(
-    'mapboxLocationInputVariable.js'), trim_blocks=True)
+MAP_MAPBOX_LOCATION_INPUT_HTML = asset_storage.load_jinja_text(
+    'mapbox-location-input.html')
+MAP_MAPBOX_LOCATION_INPUT_JS_HEADER = asset_storage.load_jinja_text(
+    'mapbox-location-input-header.js')
+MAP_MAPBOX_LOCATION_INPUT_JS_VARIABLE = asset_storage.load_jinja_text(
+    'mapbox-location-input-variable.js')
 
 
-MAP_DECK_SCREENGRID_OUTPUT_JS_HEADER = load_view_text(
-    'deckScreenGridOutputHeader.js')
-MAP_DECK_SCREENGRID_OUTPUT_JS_VARIABLE = JinjaTemplate(load_view_text(
-    'deckScreenGridOutputVariable.js'), trim_blocks=True)
+MAP_DECK_SCREENGRID_OUTPUT_JS_HEADER = asset_storage.load_raw_text(
+    'deck-screengrid-output-header.js')
+MAP_DECK_SCREENGRID_OUTPUT_JS_VARIABLE = asset_storage.load_jinja_text(
+    'deck-screengrid-output-variable.js')
